# -*- coding: utf-8 -*-
# Copyright 2009-2014, Red Hat, Inc.
# License: GPL-2.0+ <http://spdx.org/licenses/GPL-2.0+>
# See the LICENSE file for more details on Licensing

from libtaskotron.directives import bash_directive
from libtaskotron.exceptions import TaskotronDirectiveError
from dingus import Dingus
import os
import pytest
import subprocess

OUTPUT = "Piko a Rybi prsty"
PATH = os.path.realpath(__file__)


class TestCheckCommand(object):
    def test_command_present(self, monkeypatch):
        test_params = {'command': 'cmd.exe'}
        test_arg_data = {'task': PATH}
        test_directive = bash_directive.BashDirective()

        stub_check_output = Dingus()
        stub_check_output.return_value = OUTPUT

        monkeypatch.setattr(subprocess, 'check_output', stub_check_output)

        output = test_directive.process(test_params, test_arg_data)

        assert output == OUTPUT

    def test_command_not_present(self, monkeypatch):
        test_params = {'commond': 'cmd.exe'}
        test_arg_data = {'task': PATH}
        test_directive = bash_directive.BashDirective()

        monkeypatch.setattr(subprocess, 'check_output', Dingus())

        with pytest.raises(TaskotronDirectiveError):
            test_directive.process(test_params, test_arg_data)

    def test_existing_command(self):
        test_params = {'command': 'echo -n %s' % OUTPUT}
        test_arg_data = {'task': PATH}
        test_directive = bash_directive.BashDirective()

        output = test_directive.process(test_params, test_arg_data)

        assert output == OUTPUT

    def test_non_existing_command(self):
        test_params = {'command': 'ocho -n %s' % OUTPUT}
        test_arg_data = {'task': PATH}
        test_directive = bash_directive.BashDirective()

        with pytest.raises(TaskotronDirectiveError):
            test_directive.process(test_params, test_arg_data)

    def test_zero_returncode(self):
        test_params = {'command': 'true'}
        test_arg_data = {'task': PATH}
        test_directive = bash_directive.BashDirective()

        output = test_directive.process(test_params, test_arg_data)

        assert output == ""

    def test_nonzero_returncode(self):
        test_params = {'command': 'false'}
        test_arg_data = {'task': PATH}
        test_directive = bash_directive.BashDirective()

        with pytest.raises(TaskotronDirectiveError):
            test_directive.process(test_params, test_arg_data)
